(function () {
  'use strict';

  var fs = qg.getFileSystemManager ? qg.getFileSystemManager() : null;
  var overrideFsUtils = {
    readCompressedFileSync: function (filePath) {
      var compressionAlgorithm = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'br';
      try {
        return fs.readCompressedFileSync({
          filePath: filePath,
          compressionAlgorithm: compressionAlgorithm
        });
      } catch (e) {
        console.warn("readCompressedFileSync failed: path: ".concat(filePath, ", message: ").concat(e.message));
        return new Error(e.message);
      }
    },
    readJsonSync: function readJsonSync(path) {
      try {
        var str = fs.readFileSync(path, 'utf8');
        return JSON.parse(str);
      } catch (e) {
        console.warn("Read json failed: path: ".concat(path, " message: ").concat(e.message));
        return new Error(e.message);
      }
    },
    unzip: function unzip(zipFilePath, targetPath, onComplete) {
      fs.unzip({
        zipFilePath: zipFilePath,
        targetPath: targetPath,
        success: function success() {
          onComplete && onComplete(null);
        },
        fail: function fail(res) {
          console.warn("unzip failed: path: ".concat(zipFilePath, " message: ").concat(res.errMsg));
          onComplete && onComplete(new Error("unzip failed: ".concat(res.errMsg)));
        }
      });
    }
  };
  window.fsUtils = Object.assign(window.fsUtils, overrideFsUtils);

  var localStorage = {
    get length() {
      var ref = qg.getStorageInfoSync();
      var keys = ref.keys;
      return keys.length;
    },
    key: function key(n) {
      var ref = qg.getStorageInfoSync();
      var keys = ref.keys;
      return keys[n];
    },
    getItem: function getItem(key) {
      return qg.getStorageSync(key);
    },
    setItem: function setItem(key, value) {
      return qg.setStorageSync(key, value);
    },
    removeItem: function removeItem(key) {
      qg.removeStorageSync(key);
    },
    clear: function clear() {
      qg.clearStorageSync();
    }
  };
  window.localStorage = localStorage;

})();
